@@ -5,7 +5,7 @@ import traceback
 import io
 from multiprocessing import Process, Pipe, Queue
 from typing import BinaryIO
-from qualtrim import quality_trim_index  # because qualtrim is in the same folder shouldn't need ultraplex.qualtrim?
+from qualtrim_new import quality_trim_index  # because qualtrim is in the same folder shouldn't need ultraplex.qualtrim?
 from ultraplex.modifiers import AdapterCutter, ModificationInfo
 from ultraplex.adapters import BackAdapter
 import gzip
